==> react-ui-base-0.1.5.tgz: package/src/components/example-component-base/component.tsx <==
import * as React from 'react';

export interface IExampleComponentBaseProps {
    description?: string;
    example: JSX.Element;
    source?: string;
}

export interface IExampleComponentBaseState {
    isCodeShowing: boolean;
}

export class ExampleComponentBase extends React.Component<IExampleComponentBaseProps, IExampleComponentBaseState> {
    constructor(props: IExampleComponentBaseProps) {
        super(props);

        this.state = {
            isCodeShowing: false
        };
    }
    render() {
        return (
            <div className="sci-react-ui-base-example-component-base">
                <div className="header">
                    <div className="description">{this.props.description}</div>
                    {
                        this.props.source &&
                        <button className="toggle" onClick={this.toggleView}>{this.computeToggleButtonName()}</button>}
                </div>
                <div className="visual">
                    {
                        !this.state.isCodeShowing &&
                        this.props.example
                    }
                    {
                        this.state.isCodeShowing &&
                        <pre>
                            <code>
                                {this.props.source}
                            </code>
                        </pre>
                    }
                </div>
            </div>
        );
    }

    private computeToggleButtonName() {
        if (this.state.isCodeShowing) {
            return "Show example";
        } else {
            return "Show code";
        }
    }

    private toggleView = () => {
        this.setState({
            isCodeShowing: !this.state.isCodeShowing
        });
    };
}

==> react-ui-base-0.4.1.tgz: package/src/components/example-component-base/component.tsx <==
import * as React from 'react';
import { CodeHighlighter } from '../code-highlighter';

export interface IExampleComponentBaseProps {
    description?: string;
    example: JSX.Element;
    source?: string;
}

export interface IExampleComponentBaseState {
    isCodeShowing: boolean;
}

export class ExampleComponentBase extends React.Component<IExampleComponentBaseProps, IExampleComponentBaseState> {
    constructor(props: IExampleComponentBaseProps) {
        super(props);

        this.state = {
            isCodeShowing: false
        };
    }
    render() {
        return (
            <div className="sci-react-ui-base-example-component-base">
                <div className="header">
                    <div className="description">{this.props.description}</div>
                    {
                        this.props.source &&
                        <button className="toggle" onClick={this.toggleView}>{this.computeToggleButtonName()}</button>}
                </div>
                <div className="visual">
                    {
                        !this.state.isCodeShowing &&
                        this.props.example
                    }
                    {
                        this.state.isCodeShowing && this.props.source &&
                        <CodeHighlighter javascriptSourceCode={this.props.source} />
                    }
                </div>
            </div>
        );
    }

    private computeToggleButtonName() {
        if (this.state.isCodeShowing) {
            return "Show example";
        } else {
            return "Show code";
        }
    }

    private toggleView = () => {
        this.setState({
            isCodeShowing: !this.state.isCodeShowing
        });
    };
}
